@@ -1,6 +1,4 @@
 #
-# Copyright 2015, 2016  Human Longevity, Inc.
-#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -13,10 +11,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-"""
-DisDat constants
-
-"""
 
 _MANAGED_OBJECTS = "objects"   # directory in the context for objects
 
