@@ -1,6 +1,4 @@
 #
-# Copyright 2015, 2016, 2017  Human Longevity, Inc.
-#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -13,9 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-"""
-A DisDat context
-"""
+
 import os
 import json
 import glob
@@ -24,8 +20,6 @@ import shutil
 from sqlalchemy import create_engine
 import pandas as pd
 import numpy as np
-import luigi
-from luigi.contrib.s3 import S3Target
 import urllib
 import boto3
 
@@ -35,7 +29,6 @@ import disdat.hyperframe as hyperframe
 import disdat.common as common
 import disdat.utility.aws_s3 as aws_s3
 from disdat.common import DisdatConfig
-from disdat.db_link import DBLink
 from disdat import logger as _logger
 
 
@@ -660,6 +653,30 @@ class DataContext(object):
 
         return local_dir, _provided_uuid, remote_dir
 
+    @staticmethod
+    def rm_bundle_dir(output_path, uuid):
+        """
+        We created a directory (managed path) to hold the bundle and any files.   The files have been
+        copied in.   Removing the directory removes any created files.
+
+        ASSUMES:  That we haven't actually updated the local DB with information on this bundle.
+
+        Args:
+            output_path (str):
+            uuid (str):
+            db_targets (list(DBTarget)):
+        Returns:
+            None
+        """
+        try:
+            shutil.rmtree(output_path, ignore_errors=True)
+            os.rmdir(output_path)
+            # TODO: if people create s3 files, s3 file targets, inside of an s3 context,
+            # TODO: then we will have to clean those up as well.
+        except IOError as why:
+            _logger.error("Removal of hyperframe directory {} failed with error {}. Continuing removal...".format(
+                uuid, why))
+
     def rm_hframe(self, hfr_uuid):
         """
         Given a hfr_uuid, remove the hyperframe from the context.
@@ -800,7 +817,6 @@ class DataContext(object):
 
         return [(src, dst) for src, dst in zip(to_copy_files, dst_files)]
 
-
     def atomic_update_hframe(self, hfr):
         """
         Given an HFR that has new meta information, such as tags, update the version on disk atomically,
@@ -974,10 +990,10 @@ class DataContext(object):
 
             copied_in_series_like = []
             for src in series_like:
-                if isinstance(src, S3Target):
-                    src = src.path
-                elif isinstance(src, luigi.LocalTarget):
-                    src = urllib.parse.urljoin('file:', src.path)
+                #if isinstance(src, S3Target):
+                #    src = src.path
+                #elif isinstance(src, luigi.LocalTarget):
+                #    src = urllib.parse.urljoin('file:', src.path)
 
                 if urllib.parse.urlparse(src).scheme == 's3':
                     if remote_managed_path is not None:
@@ -1087,8 +1103,8 @@ class DataContext(object):
             src_files = [src_files]
 
         for src_path in src_files:
-            if isinstance(src_path, luigi.LocalTarget) or isinstance(src_path, S3Target):
-                src_path = src_path.path
+            #if isinstance(src_path, luigi.LocalTarget) or isinstance(src_path, S3Target):
+            #    src_path = src_path.path
 
             src_urlparse = urllib.parse.urlparse(src_path)
 
@@ -1179,21 +1195,16 @@ class DataContext(object):
         """
         file_set = []
 
-        if not (fr.is_local_fs_link_frame() or fr.is_s3_link_frame() or fr.is_db_link_frame()):
+        if not (fr.is_local_fs_link_frame() or fr.is_s3_link_frame()):
             _logger.error("actualize_link_urls called on non-link frame.")
             raise ValueError("actualize_link_urls called on non-link frame.")
 
         urls = fr.get_link_urls()
 
-        if fr.is_db_link_frame():
-            """ No-Op with db links """
-            return urls
-        else:
-            """ Must be s3 or local file links.  All the files in the link must be present """
-            assert urllib.parse.urlparse(urls[0]).scheme == common.BUNDLE_URI_SCHEME.replace('://', '')
-            local_dir = self.get_object_dir()
-            local_file_set = [os.path.join(local_dir, fr.hframe_uuid, f.replace(common.BUNDLE_URI_SCHEME, '')) for f in
-                              urls]
+        """ Must be s3 or local file links.  All the files in the link must be present """
+        assert urllib.parse.urlparse(urls[0]).scheme == common.BUNDLE_URI_SCHEME.replace('://', '')
+        local_dir = self.get_object_dir()
+        local_file_set = [os.path.join(local_dir, fr.hframe_uuid, f.replace(common.BUNDLE_URI_SCHEME, '')) for f in urls]
 
         # Check to see which files are present and which must stay remote
         # This can now happen with individual link localize and delocalize.
@@ -1234,7 +1245,7 @@ class DataContext(object):
         frames = hfr.get_frames(self)
         columns = []
         for fr in frames:
-            if fr.is_local_fs_link_frame() or fr.is_s3_link_frame() or fr.is_db_link_frame():
+            if fr.is_local_fs_link_frame() or fr.is_s3_link_frame():
                 src_paths = self.actualize_link_urls(fr, strip_file_scheme=True)
                 columns.append(pd.Series(data=src_paths, name=fr.pb.name))
             else:
@@ -1260,7 +1271,7 @@ class DataContext(object):
         assert len(frames) == 1
         fr = frames[0]
 
-        if fr.is_local_fs_link_frame() or fr.is_s3_link_frame() or fr.is_db_link_frame():
+        if fr.is_local_fs_link_frame() or fr.is_s3_link_frame():
             src_paths = self.actualize_link_urls(fr, strip_file_scheme=True)
             nda = np.array(src_paths)
         else:
@@ -1283,8 +1294,7 @@ class DataContext(object):
         assert len(frames) == 1
         fr = frames[0]
 
-        assert not (fr.is_local_fs_link_frame() or fr.is_s3_link_frame() or fr.is_db_link_frame()), \
-            "hfr2json, failed since this is a link frame. "
+        assert not (fr.is_local_fs_link_frame() or fr.is_s3_link_frame()), "hfr2json, failed since frame has links."
 
         nda = fr.to_ndarray()
 
@@ -1303,7 +1313,7 @@ class DataContext(object):
         assert len(frames) == 1
         fr = frames[0]
 
-        if fr.is_local_fs_link_frame() or fr.is_s3_link_frame() or fr.is_db_link_frame():
+        if fr.is_local_fs_link_frame() or fr.is_s3_link_frame():
             src_paths = self.actualize_link_urls(fr, strip_file_scheme=True)
             return np.array(src_paths)
         else:
@@ -1324,7 +1334,7 @@ class DataContext(object):
         frames = hfr.get_frames(self)
         row = []
         for fr in frames:
-            if fr.is_local_fs_link_frame() or fr.is_s3_link_frame() or fr.is_db_link_frame():
+            if fr.is_local_fs_link_frame() or fr.is_s3_link_frame():
                 src_paths = self.actualize_link_urls(fr, strip_file_scheme=True)
                 if len(src_paths) == 1:
                     row.append((fr.pb.name, src_paths[0]))
