@@ -213,111 +213,6 @@ def test_add_directory(tmpdir):
     api.delete_context(TEST_CONTEXT)
 
 
-@moto.mock_s3
-def deprecated_add_with_treat_as_bundle(tmpdir):
-    api.context(context_name=TEST_CONTEXT)
-
-    # Setup moto s3 resources
-    s3_client = boto3.client('s3')
-    s3_resource = boto3.resource('s3')
-    s3_resource.create_bucket(Bucket=TEST_BUCKET)
-
-    # Make sure bucket is empty
-    objects = s3_client.list_objects(Bucket=TEST_BUCKET)
-    assert 'Contents' not in objects, 'Bucket should be empty'
-
-    local_paths = []
-    s3_paths = []
-
-    # Create and upload test.csv file
-    key = 'test.csv'
-    test_csv_path = os.path.join(str(tmpdir), key)
-    df = pd.DataFrame({'a': [1, 2, 3], 'b': [4, 5, 6]})
-    df.to_csv(test_csv_path)
-
-    s3_resource.meta.client.upload_file(test_csv_path, TEST_BUCKET, key)
-    s3_path = "s3://{}/{}".format(TEST_BUCKET, key)
-
-    local_paths.append(test_csv_path)
-    s3_paths.append(s3_path)
-
-    # Create and uploadt test.txt file
-    key = 'text.txt'
-    test_txt_path = os.path.join(str(tmpdir), key)
-    with open(test_txt_path, 'w') as f:
-        f.write('Test')
-
-    s3_resource.meta.client.upload_file(test_txt_path, TEST_BUCKET, key)
-    s3_path = "s3://{}/{}".format(TEST_BUCKET, key)
-
-    local_paths.append(test_txt_path)
-    s3_paths.append(s3_path)
-
-    bool_values = [True, False]
-    string_values = ['a', 'b']
-    float_values = [1.3, 3.5]
-    int_values = [4, 5]
-
-    # Build bundle dataframe
-    bundle_df = pd.DataFrame({
-        'local_paths': local_paths,
-        's3_paths': s3_paths,
-        'bools': bool_values,
-        'strings': string_values,
-        'floats': float_values,
-        'ints': int_values
-    })
-
-    bundle_df_path = os.path.join(str(tmpdir), 'bundle.csv')
-    bundle_df.to_csv(bundle_df_path)
-
-    # These are now deprecated
-    # Add bundle dataframe
-
-    api.add(TEST_CONTEXT, 'test_add_bundle', bundle_df_path, treat_file_as_bundle=True)
-
-    # Assert that data in bundle is a dataframe
-    b = api.get(TEST_CONTEXT, 'test_add_bundle')
-    assert(isinstance(b.data, pd.DataFrame))
-
-    # Add bundle dataframe with tags
-    tag = {'test': 'tag'}
-    api.add(TEST_CONTEXT, 'test_add_bundle', bundle_df_path, treat_file_as_bundle=True, tags=tag)
-
-    # Assert that data in bundle is a dataframe
-    b = api.get(TEST_CONTEXT, 'test_add_bundle')
-    assert(isinstance(b.data, pd.DataFrame))
-    assert b.tags == tag, 'Tags do not match'
-
-    api.delete_context(TEST_CONTEXT)
-
-
-def deprecated_data_as_bundle_not_csv(tmpdir):
-
-    # Create Context
-    api.context(TEST_CONTEXT)
-
-    # Create test .txt file
-    test_txt_path = os.path.join(str(tmpdir), 'test.txt')
-    with open(test_txt_path, 'w') as f:
-        f.write('this should not create a bundle')
-
-    # Assert the txt file exists
-    assert os.path.exists(test_txt_path)
-
-    # Try to add file to the bundle
-    with pytest.raises(AssertionError) as ex:
-        api.add(TEST_CONTEXT, 'bad_path', test_txt_path, treat_file_as_bundle=True)
-
-    # Assert Exited with error code of 1
-    assert ex.type == AssertionError
-
-    # Make sure bundle does not exist
-    assert api.get(TEST_CONTEXT, 'test_file_as_bundle_txt_file') is None, 'Bundle should not exist'
-
-    api.delete_context(TEST_CONTEXT)
-
-
 if __name__ == '__main__':
     import tempfile
     test_single_file(tempfile.gettempdir())
\ No newline at end of file
